==> ochusha-0.4.2.1.tar.bz2: ochusha-0.4.2.1/lib/gziputils.h <==
/*
 * Copyright (c) 2003 The Ochusha Project.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 * $Id$
 */

#ifndef _GZIPUTILS_H_
#define _GZIPUTILS_H_

#include "asyncbuf.h"

#include <zlib.h>

#ifdef __cplusplus
extern "C" {
#endif

typedef struct _GzipBuffer GzipBuffer;


typedef enum
{
  GZIP_BUFFER_ERROR = -1,
  GZIP_BUFFER_INITIAL,
  GZIP_BUFFER_INFLATING,
  GZIP_BUFFER_INFLATION_DONE
} GzipBufferStatus;


GzipBuffer *gzip_buffer_new(AsyncBuffer *async_buffer);
void gzip_buffer_free(GzipBuffer *buffer);

GzipBufferStatus gzip_buffer_append_data(GzipBuffer *buffer, const char *data,
					 unsigned int length);

gboolean inflate_gzip_buffer(const char *input, unsigned int input_length,
			     char **output, unsigned int *output_length);

#ifdef __cplusplus
} // extern "C"
#endif

#endif	/* _GZIPUTILS_H_ */

==> ochusha-0.4.3.4.tar.bz2: ochusha-0.4.3.4/lib/gziputils.h <==
/*
 * Copyright (c) 2003 The Ochusha Project.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 * $Id: gziputils.h,v 1.1.1.1 2003/05/10 16:34:27 fuyu Exp $
 */

#ifndef _GZIPUTILS_H_
#define _GZIPUTILS_H_

#include "ochusha_async_buffer.h"

#include <zlib.h>

#ifdef __cplusplus
extern "C" {
#endif

typedef struct _GzipBuffer GzipBuffer;


typedef enum
{
  GZIP_BUFFER_ERROR = -1,
  GZIP_BUFFER_INITIAL,
  GZIP_BUFFER_INFLATING,
  GZIP_BUFFER_INFLATION_DONE
} GzipBufferStatus;


GzipBuffer *gzip_buffer_new(OchushaAsyncBuffer *async_buffer);
void gzip_buffer_free(GzipBuffer *buffer);

GzipBufferStatus gzip_buffer_append_data(GzipBuffer *buffer, const char *data,
					 unsigned int length);

gboolean inflate_gzip_buffer(const char *input, unsigned int input_length,
			     char **output, unsigned int *output_length);

#ifdef __cplusplus
} // extern "C"
#endif

#endif	/* _GZIPUTILS_H_ */
